@@ -25,7 +25,7 @@
 //!# Examples
 //!
 //!```
-//! extern crate parser_combinators as parser_combinators;
+//! extern crate parser_combinators;
 //! use parser_combinators::{spaces, many1, sep_by, digit, satisfy, Parser, ParserExt, ParseError};
 //! 
 //! fn main() {
@@ -55,7 +55,7 @@
 //! `fn expr(input: State<&str>) -> ParseResult<Expr, &str>`
 //!
 //!```
-//! extern crate parser_combinators as parser_combinators;
+//! extern crate parser_combinators;
 //! use parser_combinators::{between, spaces, many1, parser, sep_by, satisfy, Parser, ParserExt,
 //! ParseResult};
 //! use parser_combinators::primitives::{State, Stream};
@@ -217,6 +217,8 @@ r"
         Plus(Box<Expr>, Box<Expr>),
         Times(Box<Expr>, Box<Expr>),
     }
+
+    #[allow(unconditional_recursion)]
     fn expr(input: State<&str>) -> ParseResult<Expr, &str> {
         let word = many1(satisfy(|c| c.is_alphabetic()))
             .expected("identifier");
